@@ -25,7 +25,7 @@ from univention.appcenter.ucr import ucr_get, ucr_save
 import appcentertest as app_test
 
 
-#from shutil import rmtree
+# from shutil import rmtree
 
 
 log_to_logfile()
@@ -48,13 +48,13 @@ class Configuring:
 
     def __exit__(self, exc_type, exc_val, exc_tb):
         if self.revert == 'configure':
-            config = {key: None for key in self.settings}
+            config = {key: None for key in self.settings}  # noqa: RUF025
             configure = get_action('configure')
             configure.call(app=self.app, set_vars=config, run_script='no')
             for setting in self.settings:
                 assert ucr_get(setting) is None
         elif self.revert == 'ucr':
-            config = {key: None for key in self.settings}
+            config = {key: None for key in self.settings}  # noqa: RUF025
             ucr_save(config)
 
 
