@@ -10,7 +10,7 @@ from html import unescape
 
 import requests
 from bs4 import BeautifulSoup
-from lxml import etree
+from lxml import etree  # noqa: S410
 from requests_kerberos import OPTIONAL, HTTPKerberosAuth
 
 import univention.config_registry as configRegistry
@@ -26,7 +26,7 @@ def errors():
         'The password has expired and must be renewed.': SamlPasswordExpired,
         'Account expired.': SamlAccountExpired,  # simplesamlphp
         'The account has expired.': SamlAccountExpired,  # keycloak
-        'Invalid username or password.': SamlAuthenticationFailed,  # keycloak
+        'The authentication has failed, please login again.': SamlAuthenticationFailed,  # keycloak
         'Incorrect username or password.': SamlAuthenticationFailed,  # simplesamlphp
         'Account not verified.': SamlAccountNotVerified,
         'Changing password failed.': SamlPasswordChangeFailed,  # simplesamlphp
