@@ -12,6 +12,7 @@
 
 import datetime
 import email
+import subprocess
 from urllib.parse import parse_qs, urlparse
 
 import pytest
@@ -42,6 +43,15 @@ def activate_self_registration():
         yield ucr
 
 
+@pytest.fixture(autouse=True)
+def kill_umc_module_process():
+    print("kill umc module processes")
+    subprocess.call(['pkill', '-f', '/usr/sbin/univention-management-console-module'])
+    yield
+    print("kill umc module processes")
+    subprocess.call(['pkill', '-f', '/usr/sbin/univention-management-console-module'])
+
+
 @pytest.fixture()
 def readudm():
     return UDM.machine().version(2)
