@@ -23,7 +23,7 @@ from univention.testing.browser.lib import UMCBrowserTest
 from univention.testing.browser.systemdiagnostics import SystemDiagnostic
 
 
-_ = Translation("ucs-test-browser").translate
+_ = Translation('ucs-test-browser').translate
 
 PLUGIN_DIR = Path(plugins.__file__).parent
 
@@ -46,7 +46,7 @@ def plugin_data() -> Generator[PluginData, None, None]:
     if p_data.plugin_path.exists():
         p_data.plugin_path.unlink()
 
-    pyc_file = Path(f"{p_data}c")
+    pyc_file = Path(f'{p_data}c')
     if pyc_file.exists():
         pyc_file.unlink()
 
@@ -59,9 +59,9 @@ def create_diagnostics_plugin() -> PluginData:
     temp_file = tempfile.NamedTemporaryFile(delete=False)
     temp_file.close()
     plugin_data = PluginData(
-        "133_system_diagnostics title",
-        "133_system_diagnostics description",
-        "test_action label",
+        '133_system_diagnostics title',
+        '133_system_diagnostics description',
+        'test_action label',
         Path(temp_file.name),
         plugin_path,
     )
@@ -99,7 +99,7 @@ actions = {{
 }}
 """.strip()
 
-    with open(plugin_path, "w") as fd:
+    with open(plugin_path, 'w') as fd:
         fd.write(plugin)
 
 
@@ -108,13 +108,13 @@ def get_plugin_path() -> Path:
     while plugin_path.exists():
         plugin_path = get_random_plugin_path()
 
-    print(f"Test plugin path is {plugin_path}")
+    print(f'Test plugin path is {plugin_path}')
 
     return plugin_path
 
 
 def get_random_plugin_path() -> Path:
-    plugin_name = f"{uts.random_string(length=10, alpha=True, numeric=False)}.py"
+    plugin_name = f'{uts.random_string(length=10, alpha=True, numeric=False)}.py'
     return PLUGIN_DIR / plugin_name
 
 
@@ -124,10 +124,10 @@ def test_system_diagnostics(umc_browser_test: UMCBrowserTest, plugin_data: Plugi
     system_diag = SystemDiagnostic(umc_browser_test)
     system_diag.navigate()
 
-    expect(page.get_by_role("button", name=plugin_data.title)).to_be_hidden()
+    expect(page.get_by_role('button', name=plugin_data.title)).to_be_hidden()
 
-    with open(plugin_data.temp_file_name, "w") as fd:
-        fd.write("FAIL")
+    with open(plugin_data.temp_file_name, 'w') as fd:
+        fd.write('FAIL')
 
     system_diag.run_system_diagnostics()
-    expect(page.get_by_role("button", name=plugin_data.title)).to_be_visible()
+    expect(page.get_by_role('button', name=plugin_data.title)).to_be_visible()
