@@ -17,7 +17,7 @@ from univention.testing.browser.lib import UMCBrowserTest
 from univention.testing.browser.sidemenu import SideMenu
 
 
-_ = Translation("ucs-test-browser").translate
+_ = Translation('ucs-test-browser').translate
 
 
 def test_side_menu_navigation(umc_browser_test: UMCBrowserTest):
@@ -25,17 +25,17 @@ def test_side_menu_navigation(umc_browser_test: UMCBrowserTest):
     side_menu.navigate()
     side_menu.open_user_settings()
 
-    change_password_locator = side_menu.page.get_by_text(_("Change password"))
+    change_password_locator = side_menu.page.get_by_text(_('Change password'))
     expect(change_password_locator, "Expect 'Change password' to be visible when on the side menu user settings").to_be_visible()
 
     side_menu.back()
 
-    user_settings_locator = side_menu.page.locator("#umcMenuUserSettings")
+    user_settings_locator = side_menu.page.locator('#umcMenuUserSettings')
     expect(user_settings_locator, "Expect 'User settings' to be visible after clicking back from User settings").to_be_visible()
 
     side_menu.toggle_menu()
     # sleep to allow animation
     time.sleep(2)
     side_menu.toggle_menu()
-    user_settings_locator = side_menu.page.locator("#umcMenuUserSettings")
+    user_settings_locator = side_menu.page.locator('#umcMenuUserSettings')
     expect(user_settings_locator, "Expect 'User settings' to be visible after closing and opening the side menu").to_be_visible()
