@@ -4,9 +4,10 @@
 ## roles: [domaincontroller_master,domaincontroller_backup,domaincontroller_slave,memberserver]
 ## tags: [producttest]
 ## env:
-##   LOCUST_SPAWN_RATE: "10"
+##   LOCUST_SPAWN_RATE: "12"
 ##   LOCUST_RUN_TIME: "20m"
-##   LOCUST_USERS: "5000"
+##   LOCUST_USERS: "1400"
+##   LOCUST_THROUGHPUT: "100"
 ##   LOCUST_USER_CLASSES: SAMLSessionRefresh
 ##   USE_KEYCLOAK: "1"
 ##   WAIT_MAX: "180"
@@ -18,8 +19,9 @@ import os
 from urllib.parse import urlparse
 
 import gevent
-from locust import FastHttpUser, constant, events, run_single_user, task
-from locust_jmeter_listener import JmeterListener
+from locust import FastHttpUser, events, run_single_user, task
+from locust_plugins import constant_total_ips
+from locust_plugins.listeners.jmeter import JmeterListener
 from utils import TIMEOUT, do_saml_iframe_session_refresh, get_credentials, login_via_saml
 
 
@@ -27,7 +29,9 @@ WAIT_MAX = int(os.environ.get('WAIT_MAX', '120'))
 
 
 class SAMLSessionRefresh(FastHttpUser):
-    wait_time = constant(WAIT_MAX)
+    throughput = int(os.environ.get('LOCUST_THROUGHPUT', '100'))
+    print(f'Running with a target throughput of {throughput}')
+    wait_time = constant_total_ips(throughput)
     network_timeout = TIMEOUT
     connection_timeout = TIMEOUT
     insecure = True
@@ -35,11 +39,13 @@ class SAMLSessionRefresh(FastHttpUser):
     @events.init.add_listener
     def on_init(environment, **_kwargs):
         environment.stats.use_response_times_cache = True
-        JmeterListener(environment, results_filename='/mnt/locust/jmeter_results_SAMLSessionRefresh.csv')
+        JmeterListener(env=environment, results_filename='/mnt/locust/jmeter_results_SAMLSessionRefresh.csv', timestamp_format='%Y/%m/%d %H:%M:%S')
 
-    def on_start(self):
+    @task
+    def login_refresh_logout(self):
         self.username, self.password = get_credentials()
 
+        self.client.cookiejar.clear()
         next_path = ''
 
         # 1. GET /
@@ -116,10 +122,6 @@ class SAMLSessionRefresh(FastHttpUser):
                 resp.failure(f'Expected 200: {resp.status_code}')
                 return
 
-    @task
-    def dummy(self):
-        pass
-
 
 if __name__ == '__main__':
     run_single_user(SAMLSessionRefresh)
