@@ -364,6 +364,8 @@ COMMON_EXCEPTIONS = (
     E(r"_ldb.LdbError: \(1, 'LDAP client internal error: NT_STATUS_INVALID_PARAMETER'\)", ['univention-samba4-site-tool.py'], 54592),
     E(r"AssertionError: Attribute \(username\) is parsed wrong as.*", ['103_ucsschool_smbstatus_parser.py'], 54591),
     E(r"optparse.OptionConflictError: option.*authentication-file", ['univention-samba4-site-tool.py'], 55082),
+    E(r"AttributeError: 'Logger' object has no attribute '_fallbackLogger'", ['_reverse_umc_module_logger']),
+    E(r"ImportError: cannot import name 'pki_option' from 'univention.admin.certificate' (/usr/lib/python3/dist-packages/univention/admin/certificate.py)"),
 )
 
 
