@@ -137,7 +137,8 @@ class Interactions:
 
     def open_and_close_module(self, module_name: str, wait_for_network_idle: bool = False):
         self.open_module(_(module_name), wait_for_network_idle=wait_for_network_idle)
-        self.page.get_by_role('button', name=_('Close')).click()
+        # give it a bit more time, e.g. system diagnostic runs longer
+        self.page.get_by_role('button', name=_('Close')).click(timeout=60000)
 
     def get_available_modules(self) -> List[str]:
         self.page.locator('.umcModuleSearchToggleButton').click()
@@ -180,7 +181,7 @@ class Interactions:
         logger.info('Clicked the module button')
         if expect_response is None and wait_for_network_idle:
             logger.info('Waiting for network to be idle...')
-            self.page.wait_for_load_state("networkidle")
+            self.page.wait_for_load_state("networkidle", timeout=30 * 3 * 1000)
 
         if module_name == 'App Center':
             from univention.testing.browser.appcenter import AppCenter, wait_for_final_query
