@@ -5,7 +5,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2023 Univention GmbH
+# Copyright 2023-2024 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -48,7 +48,7 @@ logger = logging.getLogger(__name__)
 KB = 1000
 MB = KB * 1000
 
-_ = Translation("ucs-test-framework").translate
+_ = Translation('ucs-test-framework').translate
 
 
 class PackageAction(enum.Enum):
@@ -57,19 +57,19 @@ class PackageAction(enum.Enum):
 
     def __str__(self) -> str:
         if self == PackageAction.Install:
-            return _("Install")
+            return _('Install')
         elif self == PackageAction.Uninstall:
-            return _("Uninstall")
+            return _('Uninstall')
 
-        return ""
+        return ''
 
     def expected_status(self) -> str:
         if self == PackageAction.Install:
-            return _("installed")
+            return _('installed')
         elif self == PackageAction.Uninstall:
-            return _("not installed")
+            return _('not installed')
 
-        return ""
+        return ''
 
 
 class PackageManagement:
@@ -78,11 +78,11 @@ class PackageManagement:
     def __init__(self, tester: UMCBrowserTest) -> None:
         self.tester: UMCBrowserTest = tester
         self.page: Page = tester.page
-        self.module_name = _("Package Management")
-        self.grid_load_url = re.compile(".*univention/command/appcenter/packages/query.*")
-        self.initial_grid_load_url = re.compile(".*univention/command/appcenter/packages/sections.*")
+        self.module_name = _('Package Management')
+        self.grid_load_url = re.compile('.*univention/command/appcenter/packages/query.*')
+        self.initial_grid_load_url = re.compile('.*univention/command/appcenter/packages/sections.*')
 
-    def navigate(self, username="Administrator", password="univention"):
+    def navigate(self, username='Administrator', password='univention'):
         self.tester.login(username, password)
         self.tester.open_module(self.module_name, self.initial_grid_load_url)
 
@@ -92,7 +92,7 @@ class PackageManagement:
 
         :return: the package name
         """
-        logger.info("Trying to find small, uninstalled package with no dependencies and recommends")
+        logger.info('Trying to find small, uninstalled package with no dependencies and recommends')
         cache = apt.cache.Cache()
         cache.update()
         cache.open()
@@ -105,40 +105,40 @@ class PackageManagement:
                 and not package.candidate.recommends
                 and not package.candidate.dependencies
             ):
-                logger.info("Found %s" % package)
+                logger.info('Found %s' % package)
                 return package.name
 
-        raise Exception("Failed to find a small package")
+        raise Exception('Failed to find a small package')
 
     def search_for_package(self, name: str):
-        search_bar = self.page.locator("[name=pattern]")
-        search_bar.fill("")
+        search_bar = self.page.locator('[name=pattern]')
+        search_bar.fill('')
         search_bar.type(name)
         with self.page.expect_response(self.grid_load_url):
-            search_bar.press("Enter")
+            search_bar.press('Enter')
 
     def do_package_action(self, name: str, action: PackageAction):
-        logger.info("Action %s on package %s" % (action, name))
+        logger.info('Action %s on package %s' % (action, name))
         self.search_for_package(name)
         self.tester.check_checkbox_in_grid_by_name(name, 0)
-        self.page.get_by_role("button", name=str(action), exact=True).click()
+        self.page.get_by_role('button', name=str(action), exact=True).click()
 
         self.handle_confirmation_dialog(str(action))
         self.handle_action_dialog()
-        logger.info("%s done" % action)
+        logger.info('%s done' % action)
         with self.page.expect_response(self.grid_load_url):
             pass
 
     def handle_confirmation_dialog(self, action: str):
-        dialog = self.page.get_by_role("dialog", name=_("Confirmation"))
-        dialog.get_by_role("button", name=action).click()
+        dialog = self.page.get_by_role('dialog', name=_('Confirmation'))
+        dialog.get_by_role('button', name=action).click()
         expect(dialog).to_have_count(0)
 
     def handle_action_dialog(self):
-        dialog = self.page.get_by_role("dialog")
+        dialog = self.page.get_by_role('dialog')
         expect(dialog).to_have_count(0, timeout=3 * MIN)
 
-        pbar = self.page.get_by_role("progressbar")
+        pbar = self.page.get_by_role('progressbar')
         expect(pbar).to_have_count(0, timeout=3 * MIN)
 
     def install_package(self, name: str):
@@ -156,6 +156,6 @@ class PackageManagement:
 
         :param expected: If expected is `PackageAction.Install` this function will make sure that the package has been _installed_ and vice versa.
         """
-        status_cell = self.page.get_by_role("grid").get_by_role("gridcell").get_by_text(expected.expected_status())
+        status_cell = self.page.get_by_role('grid').get_by_role('gridcell').get_by_text(expected.expected_status())
         expect(status_cell).to_have_count(1)
         expect(status_cell).to_be_visible()
