@@ -33,6 +33,7 @@
 import os
 import time
 from pathlib import Path
+from typing import Union
 from urllib.parse import quote
 
 from playwright.sync_api import BrowserContext, Page, expect
@@ -41,7 +42,7 @@ from univention.testing.browser import logger
 from univention.testing.browser.lib import SEC
 
 
-def check_for_backtrace(page: Page):
+def check_for_backtrace(page: Page, page_index: int = 0):
     show_backtrace_button = page.get_by_role('button', name='Show server error message')
     notification_502_error = page.get_by_text('An unknown error with status code 502 occurred').first
     try:
@@ -52,7 +53,7 @@ def check_for_backtrace(page: Page):
                 'region',
                 name='Hide server error message',
             )
-            logger.info('Recorded backtrace')
+            logger.info(f'Recorded backtrace on page {page_index}')
             print(backtrace_container.inner_text())
         else:
             logger.info('An unknown error with status code 502 occurred while connecting to the server.')
@@ -60,33 +61,40 @@ def check_for_backtrace(page: Page):
         pass
 
 
+def print_path_in_jenkins(name: str, ucr, typ='screenshot'):
+    subfolder = ''
+    if os.environ.get('JENKINS_WS'):
+        if 'master' not in ucr.get('server/role'):
+            subfolder = f"{ucr.get('hostname')}/"
+        full_url = f"{os.environ['JENKINS_WS']}ws/test/{quote(subfolder)}browser/{quote(name)}"
+        logger.info('Browser %s URL: %s' % (typ, full_url))
+
+
+def save_screenshot(page: Page, node_name, path: Path, ucr, page_index: int = 0, timestamp: Union[int, None] = None):
+    ts = timestamp or time.time_ns()
+
+    screenshot_filename = path / f'{ts}-{node_name}-page_{page_index}.jpeg'
+
+    page.screenshot(path=screenshot_filename)
+
+    print_path_in_jenkins(screenshot_filename.name, ucr)
+
+
 def save_trace(
-    page: Page,
     context: BrowserContext,
     node_name: str,
     path: Path,
     ucr,
     tracing_stop_chunk: bool = False,
+    timestamp: Union[int, None] = None
 ):
-    ts = time.time_ns()
+    ts = timestamp or time.time_ns()
 
-    screenshot_filename = path / f'{ts}-{node_name}.jpeg'
     trace_filename = path / f'{ts}-{node_name}_trace.zip'
 
-    page.screenshot(path=screenshot_filename)
-
     if tracing_stop_chunk:
         context.tracing.stop_chunk(path=trace_filename)
     else:
         context.tracing.stop(path=trace_filename)
 
-    if os.environ.get('JENKINS_WS'):
-        if 'master' not in ucr.get('server/role'):
-            subfolder = f"{ucr.get('hostname')}/"
-        else:
-            subfolder = ''
-
-        browser_trace_url = f"{os.environ['JENKINS_WS']}ws/test/{quote(subfolder)}browser/{quote(trace_filename.name)}"
-        browser_screenshot_url = f"{os.environ['JENKINS_WS']}ws/test/{quote(subfolder)}browser/{quote(screenshot_filename.name)}"
-        logger.info('Browser trace URL: %s' % browser_trace_url)
-        logger.info('Browser screenshot URL: %s' % browser_screenshot_url)
+    print_path_in_jenkins(trace_filename.name, ucr, 'trace')
