@@ -5,7 +5,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2016-2023 Univention GmbH
+# Copyright 2016-2024 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -32,11 +32,12 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
+from __future__ import annotations
 
 import pprint
 import sys
 from html.parser import HTMLParser
-from typing import Any, Iterable, Optional, Tuple  # noqa: F401
+from typing import Any, Iterable, Tuple
 
 import requests
 
@@ -50,8 +51,7 @@ class Client(_Client):
     print_request_data = True
 
     @classmethod
-    def get_test_connection(cls, hostname=None, *args, **kwargs):
-        # type: (Optional[str], *Any, **Any) -> Client
+    def get_test_connection(cls, hostname: str | None = None, *args: Any, **kwargs: Any) -> Client:
         ucr = ConfigRegistry()
         ucr.load()
         username = ucr.get('tests/domainadmin/account')
@@ -59,8 +59,7 @@ class Client(_Client):
         password = ucr.get('tests/domainadmin/pwd')
         return cls(hostname, username, password, *args, **kwargs)
 
-    def umc_command(self, *args, **kwargs):
-        # type: (*Any, **Any) -> Client
+    def umc_command(self, *args: Any, **kwargs: Any) -> Client:
         self.print_request_data = kwargs.pop('print_request_data', True)
         self.print_response = kwargs.pop('print_response', True)
         try:
@@ -69,8 +68,7 @@ class Client(_Client):
             self.print_request_data = True
             self.print_response = True
 
-    def request(self, method, path, data=None, headers=None):
-        # type: (str, str, Any, Any) -> Any
+    def request(self, method: str, path: str, data: Any = None, headers: Any = None) -> Any:
         print('')
         print('*** UMC request: "%s %s" %s' % (method, path, '(%s)' % (data.get('flavor'),) if isinstance(data, dict) else ''))
         if self.print_request_data:
@@ -94,24 +92,21 @@ class SamlLoginError(Exception):
 
 
 class GetHtmlTagValue(HTMLParser):
-    def __init__(self, tag, condition, value_name):
-        # type: (str, Tuple[str, str], str) -> None
+    def __init__(self, tag: str, condition: Tuple[str, str], value_name: str) -> None:
         self.tag = tag
         self.condition = condition
         self.value_name = value_name
-        self.value = None  # type: Optional[str]
+        self.value: str | None = None
         super().__init__()
 
-    def handle_starttag(self, tag, attrs):
-        # type: (str, Iterable[Tuple[str, Optional[str]]]) -> None
+    def handle_starttag(self, tag: str, attrs: Iterable[Tuple[str, str | None]]) -> None:
         if tag == self.tag and self.condition in attrs:
             for attr in attrs:
                 if attr[0] == self.value_name:
                     self.value = attr[1]
 
 
-def get_html_tag_value(page, tag, condition, value_name):
-    # type: (str, str, Tuple[str, str], str) -> str
+def get_html_tag_value(page: str, tag: str, condition: Tuple[str, str], value_name: str) -> str:
     htmlParser = GetHtmlTagValue(tag, condition, value_name)
     htmlParser.feed(page)
     htmlParser.close()
@@ -121,12 +116,10 @@ def get_html_tag_value(page, tag, condition, value_name):
 
 class ClientSaml(Client):
 
-    def authenticate(self, *args):
-        # type: (*Any) -> None
+    def authenticate(self, *args: Any) -> None:
         self.authenticate_saml(*args)
 
-    def authenticate_saml(self, *args):
-        # type: (*Any) -> None
+    def authenticate_saml(self, *args: Any) -> None:
         self.__samlSession = requests.Session()
 
         saml_login_url = "https://%s/univention/saml/" % self.hostname
@@ -139,8 +132,7 @@ class ClientSaml(Client):
         self._send_saml_response_to_sp(saml_idp_login_ans)
         self.cookies.update(self.__samlSession.cookies.items())
 
-    def _login_at_idp_with_credentials(self, saml_login_page):
-        # type: (Any) -> Any
+    def _login_at_idp_with_credentials(self, saml_login_page: Any) -> Any:
         """Send login form to IdP"""
         auth_state = get_html_tag_value(saml_login_page.text, 'input', ('name', 'AuthState'), 'value')
         data = {'username': self.username, 'password': self.password, 'AuthState': auth_state}
@@ -151,8 +143,7 @@ class ClientSaml(Client):
             raise SamlLoginError(f'Login failed?:\n{saml_idp_login_ans.text}')
         return saml_idp_login_ans
 
-    def _send_saml_response_to_sp(self, saml_idp_login_ans):
-        # type: (Any) -> None
+    def _send_saml_response_to_sp(self, saml_idp_login_ans: Any) -> None:
         sp_login_url = get_html_tag_value(saml_idp_login_ans.text, 'form', ('method', 'post'), 'action')
         saml_msg = get_html_tag_value(saml_idp_login_ans.text, 'input', ('name', 'SAMLResponse'), 'value')
         relay_state = get_html_tag_value(saml_idp_login_ans.text, 'input', ('name', 'RelayState'), 'value')
